==> Bencher-Scenarios-Perl-0.050.tar.gz: Bencher-Scenarios-Perl-0.050/lib/Bencher/Scenarios/Perl.pm <==
package Bencher::Scenarios::Perl;

our $DATE = '2019-10-20'; # DATE
our $VERSION = '0.050'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: A collection of bencher scenarios to benchmark perl

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::Perl - A collection of bencher scenarios to benchmark perl

=head1 VERSION

This document describes version 0.050 of Bencher::Scenarios::Perl (from Perl distribution Bencher-Scenarios-Perl), released on 2019-10-20.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::Perl::5220Perf_length>

=item * L<Bencher::Scenario::Perl::5200Perf_return>

=item * L<Bencher::Scenario::Perl::Startup>

=item * L<Bencher::Scenario::Perl::Swap>

=item * L<Bencher::Scenario::Perl::Hash>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Perl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Bencher-Scenarios-Perl-0.051.tar.gz: Bencher-Scenarios-Perl-0.051/lib/Bencher/Scenarios/Perl.pm <==
package Bencher::Scenarios::Perl;

our $DATE = '2021-07-03'; # DATE
our $VERSION = '0.051'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: A collection of bencher scenarios to benchmark perl

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::Perl - A collection of bencher scenarios to benchmark perl

=head1 VERSION

This document describes version 0.051 of Bencher::Scenarios::Perl (from Perl distribution Bencher-Scenarios-Perl), released on 2021-07-03.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::Perl::5220Perf_length>

=item * L<Bencher::Scenario::Perl::5200Perf_return>

=item * L<Bencher::Scenario::Perl::Swap>

=item * L<Bencher::Scenario::Perl::Hash>

=back

=head1 CONTRIBUTOR

=for stopwords perlancar (@pc-office)

perlancar (@pc-office) <perlancar@gmail.com>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Perl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2019, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
